===========================
boatd - sailing boat daemon 
===========================

Experimental robotic sailing boat daemon.

.. image:: https://img.shields.io/pypi/v/boatd.svg
    :target: https://pypi.python.org/pypi/boatd

.. image:: https://img.shields.io/travis/boatd/boatd.svg
    :target: https://travis-ci.org/boatd/boatd

.. image:: https://img.shields.io/coveralls/boatd/boatd/master.svg
    :target: https://coveralls.io/r/boatd/boatd?branch=master

Documentation is located at http://boatd.readthedocs.io/.

License
=======

Copyright (c) 2013-2016 Louis Taylor <louis@kragniz.eu>

Boatd is free software: you can redistribute it and/or modify it under the
terms of the GNU Lesser General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

See [COPYING](COPYING) for more information.
